==> kubernetes-model-flowcontrol-6.4.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/LimitedPriorityLevelConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LimitedPriorityLevelConfigurationFluentImpl<A extends LimitedPriorityLevelConfigurationFluent<A>> extends BaseFluent<A> implements LimitedPriorityLevelConfigurationFluent<A>{
  public LimitedPriorityLevelConfigurationFluentImpl() {
  }
  public LimitedPriorityLevelConfigurationFluentImpl(LimitedPriorityLevelConfiguration instance) {
    this.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares()); 
    this.withLimitResponse(instance.getLimitResponse()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Integer assuredConcurrencyShares;
  private LimitResponseBuilder limitResponse;
  private Map<String,Object> additionalProperties;
  public Integer getAssuredConcurrencyShares() {
    return this.assuredConcurrencyShares;
  }
  public A withAssuredConcurrencyShares(Integer assuredConcurrencyShares) {
    this.assuredConcurrencyShares=assuredConcurrencyShares; return (A) this;
  }
  public Boolean hasAssuredConcurrencyShares() {
    return this.assuredConcurrencyShares != null;
  }
  
  /**
   * This method has been deprecated, please use method buildLimitResponse instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitResponse getLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  public LimitResponse buildLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  public A withLimitResponse(LimitResponse limitResponse) {
    _visitables.get("limitResponse").remove(this.limitResponse);
    if (limitResponse!=null){ this.limitResponse= new LimitResponseBuilder(limitResponse); _visitables.get("limitResponse").add(this.limitResponse);} else { this.limitResponse = null; _visitables.get("limitResponse").remove(this.limitResponse); } return (A) this;
  }
  public Boolean hasLimitResponse() {
    return this.limitResponse != null;
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponse() {
    return new LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNestedImpl();
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item) {
    return new LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNestedImpl(item);
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editLimitResponse() {
    return withNewLimitResponseLike(getLimitResponse());
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponse() {
    return withNewLimitResponseLike(getLimitResponse() != null ? getLimitResponse(): new LimitResponseBuilder().build());
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item) {
    return withNewLimitResponseLike(getLimitResponse() != null ? getLimitResponse(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LimitedPriorityLevelConfigurationFluentImpl that = (LimitedPriorityLevelConfigurationFluentImpl) o;
    if (assuredConcurrencyShares != null ? !assuredConcurrencyShares.equals(that.assuredConcurrencyShares) :that.assuredConcurrencyShares != null) return false;
    if (limitResponse != null ? !limitResponse.equals(that.limitResponse) :that.limitResponse != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(assuredConcurrencyShares,  limitResponse,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (assuredConcurrencyShares != null) { sb.append("assuredConcurrencyShares:"); sb.append(assuredConcurrencyShares + ","); }
    if (limitResponse != null) { sb.append("limitResponse:"); sb.append(limitResponse + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LimitResponseNestedImpl<N> extends LimitResponseFluentImpl<LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>> implements LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>,Nested<N>{
    LimitResponseNestedImpl(LimitResponse item) {
      this.builder = new LimitResponseBuilder(this, item);
    }
    LimitResponseNestedImpl() {
      this.builder = new LimitResponseBuilder(this);
    }
    LimitResponseBuilder builder;
    public N and() {
      return (N) LimitedPriorityLevelConfigurationFluentImpl.this.withLimitResponse(builder.build());
    }
    public N endLimitResponse() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/LimitedPriorityLevelConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LimitedPriorityLevelConfigurationFluentImpl<A extends LimitedPriorityLevelConfigurationFluent<A>> extends BaseFluent<A> implements LimitedPriorityLevelConfigurationFluent<A>{
  public LimitedPriorityLevelConfigurationFluentImpl() {
  }
  public LimitedPriorityLevelConfigurationFluentImpl(LimitedPriorityLevelConfiguration instance) {
    this.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares()); 
    this.withBorrowingLimitPercent(instance.getBorrowingLimitPercent()); 
    this.withLendablePercent(instance.getLendablePercent()); 
    this.withLimitResponse(instance.getLimitResponse()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Integer assuredConcurrencyShares;
  private Integer borrowingLimitPercent;
  private Integer lendablePercent;
  private LimitResponseBuilder limitResponse;
  private Map<String,Object> additionalProperties;
  public Integer getAssuredConcurrencyShares() {
    return this.assuredConcurrencyShares;
  }
  public A withAssuredConcurrencyShares(Integer assuredConcurrencyShares) {
    this.assuredConcurrencyShares=assuredConcurrencyShares; return (A) this;
  }
  public Boolean hasAssuredConcurrencyShares() {
    return this.assuredConcurrencyShares != null;
  }
  public Integer getBorrowingLimitPercent() {
    return this.borrowingLimitPercent;
  }
  public A withBorrowingLimitPercent(Integer borrowingLimitPercent) {
    this.borrowingLimitPercent=borrowingLimitPercent; return (A) this;
  }
  public Boolean hasBorrowingLimitPercent() {
    return this.borrowingLimitPercent != null;
  }
  public Integer getLendablePercent() {
    return this.lendablePercent;
  }
  public A withLendablePercent(Integer lendablePercent) {
    this.lendablePercent=lendablePercent; return (A) this;
  }
  public Boolean hasLendablePercent() {
    return this.lendablePercent != null;
  }
  
  /**
   * This method has been deprecated, please use method buildLimitResponse instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitResponse getLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  public LimitResponse buildLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  public A withLimitResponse(LimitResponse limitResponse) {
    _visitables.get("limitResponse").remove(this.limitResponse);
    if (limitResponse!=null){ this.limitResponse= new LimitResponseBuilder(limitResponse); _visitables.get("limitResponse").add(this.limitResponse);} else { this.limitResponse = null; _visitables.get("limitResponse").remove(this.limitResponse); } return (A) this;
  }
  public Boolean hasLimitResponse() {
    return this.limitResponse != null;
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponse() {
    return new LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNestedImpl();
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item) {
    return new LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNestedImpl(item);
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editLimitResponse() {
    return withNewLimitResponseLike(getLimitResponse());
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponse() {
    return withNewLimitResponseLike(getLimitResponse() != null ? getLimitResponse(): new LimitResponseBuilder().build());
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item) {
    return withNewLimitResponseLike(getLimitResponse() != null ? getLimitResponse(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LimitedPriorityLevelConfigurationFluentImpl that = (LimitedPriorityLevelConfigurationFluentImpl) o;
    if (assuredConcurrencyShares != null ? !assuredConcurrencyShares.equals(that.assuredConcurrencyShares) :that.assuredConcurrencyShares != null) return false;
    if (borrowingLimitPercent != null ? !borrowingLimitPercent.equals(that.borrowingLimitPercent) :that.borrowingLimitPercent != null) return false;
    if (lendablePercent != null ? !lendablePercent.equals(that.lendablePercent) :that.lendablePercent != null) return false;
    if (limitResponse != null ? !limitResponse.equals(that.limitResponse) :that.limitResponse != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(assuredConcurrencyShares,  borrowingLimitPercent,  lendablePercent,  limitResponse,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (assuredConcurrencyShares != null) { sb.append("assuredConcurrencyShares:"); sb.append(assuredConcurrencyShares + ","); }
    if (borrowingLimitPercent != null) { sb.append("borrowingLimitPercent:"); sb.append(borrowingLimitPercent + ","); }
    if (lendablePercent != null) { sb.append("lendablePercent:"); sb.append(lendablePercent + ","); }
    if (limitResponse != null) { sb.append("limitResponse:"); sb.append(limitResponse + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LimitResponseNestedImpl<N> extends LimitResponseFluentImpl<LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>> implements LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>,Nested<N>{
    LimitResponseNestedImpl(LimitResponse item) {
      this.builder = new LimitResponseBuilder(this, item);
    }
    LimitResponseNestedImpl() {
      this.builder = new LimitResponseBuilder(this);
    }
    LimitResponseBuilder builder;
    public N and() {
      return (N) LimitedPriorityLevelConfigurationFluentImpl.this.withLimitResponse(builder.build());
    }
    public N endLimitResponse() {
      return and();
    }
    
  }
  
}
